"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCrashOnError = exports.setCrashOnError = exports.offReload = exports.onReload = exports.setDefaultOpts = exports.meta = exports.get = exports.disableReload = exports.enableReload = exports.reload = exports.EE = exports.prependDefaultConfiguration = exports.append = void 0;
const EventEmitter = require("eventemitter3");
const _debug = require("debug");
const confidence_1 = require("@makeomatic/confidence");
const assert_1 = require("assert");
const load_config_1 = require("./load-config");
Object.defineProperty(exports, "append", { enumerable: true, get: function () { return load_config_1.append; } });
Object.defineProperty(exports, "prependDefaultConfiguration", { enumerable: true, get: function () { return load_config_1.prependDefaultConfiguration; } });
const debug = _debug('ms-conf');
// uses confidence API to access store
let store;
let defaultOpts = {};
let crashOnError = false;
const EE = new EventEmitter();
exports.EE = EE;
// use this on sighup
function reload() {
    debug('reloading configuration');
    store = new confidence_1.Store(load_config_1.loadConfiguration(crashOnError));
    EE.emit('reload', store);
}
exports.reload = reload;
// hot-reload enabler
function enableReload() {
    debug('enabling sigusr');
    process.on('SIGUSR1', reload);
    process.on('SIGUSR2', reload);
}
exports.enableReload = enableReload;
// hot-reload disabler
function disableReload() {
    debug('disabling sigusr');
    process.removeListener('SIGUSR1', reload);
    process.removeListener('SIGUSR2', reload);
}
exports.disableReload = disableReload;
function get(key, opts = defaultOpts) {
    if (!store)
        reload();
    return store.get(key, opts);
}
exports.get = get;
function meta(key, opts = defaultOpts) {
    if (!store)
        reload();
    return store.meta(key, opts);
}
exports.meta = meta;
function setDefaultOpts(opts) {
    assert_1.strict.ok(opts, 'must be an object');
    assert_1.strict.ok(typeof opts === 'object', 'must be an object');
    defaultOpts = opts;
}
exports.setDefaultOpts = setDefaultOpts;
function onReload(fn) {
    EE.on('reload', fn);
}
exports.onReload = onReload;
function offReload(fn) {
    EE.off('reload', fn);
}
exports.offReload = offReload;
function setCrashOnError(val) {
    crashOnError = val;
}
exports.setCrashOnError = setCrashOnError;
function getCrashOnError() {
    return crashOnError;
}
exports.getCrashOnError = getCrashOnError;
//# sourceMappingURL=index.js.map